.. _module_util_plugins:

Module utilities
================

.. contents::
   :local:
   :depth: 2

Module utilities contain shared code used by multiple plugins. You can write :ref:`custom module utilities <developing_module_utilities>`.

.. _enabling_module_utils:

Enabling module utilities
-------------------------

You can add a custom module utility by dropping it into a ``module_utils`` directory adjacent to your collection or role, just like any other plugin.

.. _using_module_utils:

Using module utilities
----------------------

For information on using module utilities, see :ref:`developing_module_utilities`.

.. seealso::

   :ref:`developing_modules_general`
       An introduction to creating Ansible modules
   :ref:`developing_collections`
       An guide to creating Ansible collections
   `User Mailing List <https://groups.google.com/group/ansible-devel>`_
       Have a question?  Stop by the google group!
   `irc.libera.chat <https://libera.chat/>`_
       #ansible-devel IRC chat channel
